==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ToolActionIconButtonInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionIconButtonInfoDescription } from "./ToolActionIconButtonInfoDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonInfoDescriptionMetadata.a == null) {
                ToolActionIconButtonInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonInfoDescriptionMetadata.c(ToolActionIconButtonInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconButtonInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionIconButtonInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("TooltipDelay", "Number:int");
            a.item("IsMenuOpenOnStart", "Boolean");
        }
        static d(a) {
            ToolActionIconButtonInfoDescriptionMetadata.b(a);
            a.ad("ToolActionIconButtonInfo", () => new ToolActionIconButtonInfoDescription());
            a.ac("ToolActionIconButtonInfo", ToolActionIconButtonInfoDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonInfoDescriptionMetadata, 'ToolActionIconButtonInfoDescriptionMetadata');
    ToolActionIconButtonInfoDescriptionMetadata.a = null;
    return ToolActionIconButtonInfoDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/ToolActionIconButtonInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionIconButtonInfoDescription } from "./ToolActionIconButtonInfoDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonInfoDescriptionMetadata.a == null) {
                ToolActionIconButtonInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonInfoDescriptionMetadata.c(ToolActionIconButtonInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconButtonInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionIconButtonInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("TooltipDelay", "Number:int");
            a.item("IsMenuOpenOnStart", "Boolean");
        }
        static d(a) {
            ToolActionIconButtonInfoDescriptionMetadata.b(a);
            a.ae("ToolActionIconButtonInfo", () => new ToolActionIconButtonInfoDescription());
            a.ad("ToolActionIconButtonInfo", ToolActionIconButtonInfoDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonInfoDescriptionMetadata, 'ToolActionIconButtonInfoDescriptionMetadata');
    ToolActionIconButtonInfoDescriptionMetadata.a = null;
    return ToolActionIconButtonInfoDescriptionMetadata;
})();
